@@ -15,13 +15,17 @@
 #define ENS_VERSION_MAJOR 2
 // The minor version is two digits so regular numerical comparisons of versions
 // work right.  The first minor version of a release is always 10.
-#define ENS_VERSION_MINOR 11
-#define ENS_VERSION_PATCH 3
+#define ENS_VERSION_MINOR 16
+#define ENS_VERSION_PATCH 2
 // If this is a release candidate, it will be reflected in the version name
 // (i.e. the version name will be "RC1", "RC2", etc.).  Otherwise the version
 // name will typically be a seemingly arbitrary set of words that does not
 // contain the capitalized string "RC".
-#define ENS_VERSION_NAME "The Poster Session Is Full"
+#define ENS_VERSION_NAME "Severely Dented Can Of Polyurethane"
+// Incorporate the date the version was released.
+#define ENS_VERSION_YEAR "2021"
+#define ENS_VERSION_MONTH "03"
+#define ENS_VERSION_DAY "24"
 
 namespace ens {
 
@@ -41,6 +45,14 @@ struct version
 
     return ss.str();
   }
+    
+  static inline std::string date()
+  {
+    std::stringstream ss;
+    ss << ENS_VERSION_YEAR << '-' << ENS_VERSION_MONTH << '-' << ENS_VERSION_DAY;
+
+    return ss.str();
+  }
 };
 
 } // namespace ens
